# Changelog db-rocket

## Version 1.1.2

- Pin watchdog dependency with minimum requirement
- dbrocket launch rather then trigger

## Version 1.1.1

- Error with token missing only on trigger command not on __init__ anymore.

## Version 1.1.0

- Create new binary dbrocket
- Create dbrocket setup to initalize a setup.py
- Use defualt values for trigger binary
- Improve docs

## Version 1.0.4

- Upgrade dependencies
- Add github actions ci.

## Version 1.0.3

- Remove message about spark 6 support.
- Add instruction about upgrading pip.
- Remove local cli.
- Add better error message when fails to copy to databricks

## Version 1.0.2

feature: Add support for poetry projects
test: Add test for dbrocket build process
